/**
 * Author: Andrei Heidelbacher
 * Task: Babaoarba
 * Time complexity: O(D)
 * Space complexity: O(1)
 * Expected score: 100 points
 */

#include <cmath>
#include <cassert>

#include "header.h"

using namespace std;

const double PI = acos(-1.0);

const int CLOSER = 1;
const int NOT_CLOSER = 0;
const int FOUND = -1;

bool found = false;

inline int getSign(const double direction) {
  if (found)
    return FOUND;
  const int q = makeStep(direction);
  if (q == FOUND) {
    found = true;
    return CLOSER;
  }
  assert(makeStep(direction + PI) != FOUND);
  return q;
}

inline int advance(const double direction) {
  if (found)
    return FOUND;
  const int q = makeStep(direction);
  if (q == FOUND)
    found = true;
  return q;
}

double binarySearch(double left, double right, int steps = 19) {
  int leftSign = getSign(left);
  int rightSign = getSign(right);
  assert(leftSign != rightSign);
  for (; steps > 0; --steps) {
    const double middle = 0.5 * (left + right);
    const int middleSign = getSign(middle);
    if (leftSign == middleSign)
      left = middle;
    else
      right = middle;
  }
  return 0.5 * (left + right);
}

void play() {
  double left = 0.0, right = 0.5 * PI;
  int leftSign = getSign(left);
  int rightSign = getSign(right);
  while (!found && leftSign == rightSign) {
    left = right;
    leftSign = rightSign;
    right += 0.5 * PI;
    rightSign = getSign(right);
  }
  double direction = found ? 0.0 : (binarySearch(left, right) + 0.5 * PI);
  if (advance(direction) == NOT_CLOSER)
    direction += PI;
  while (advance(direction) != FOUND);
}
