/**
 * Author: Andrei Heidelbacher
 * Task: Babaoarba
 * Grader
 */

#include <cstdio>
#include <cstdlib>
#include <cmath>

#include "header.h"

static const char IN_FILE[] = "babaoarba.in";
static const double D_MAX = 1e5;
static const double EPS = 1e-9;

static const int CLOSER = 1;
static const int NOT_CLOSER = 0;
static const int FINISHED = -1;

static int steps = 0;
static double x = 0.0;
static double y = 0.0;
static double fx;
static double fy;
static bool found = false;

static inline void result(const int score, const char *message) {
  fprintf(stdout, "%d %s\n", score, message);
  exit(0);
}

static inline void require(const bool condition, const char *message) {
  if (!condition)
    result(0, message);
}

static inline double distance(
    const double x0,
    const double y0,
    const double x1,
    const double y1) {
  return sqrt((x0 - x1) * (x0 - x1) + (y0 - y1) * (y0 - y1));
}

int makeStep(double direction) {
  require(!found, "Invalid interaction!");
  ++steps;
  const double currentDistance = distance(x, y, fx, fy);
  x += cos(direction);
  y += sin(direction);
  const double newDistance = distance(x, y, fx, fy);
  if (newDistance <= 1.0 + EPS) {
    found = true;
    return FINISHED;
  } else if (newDistance <= currentDistance - EPS) {
    return CLOSER;
  } else {
    return NOT_CLOSER;
  }
}

int main() {
  if(freopen("babaoarba.out", "w", stdout));
  FILE *in = fopen(IN_FILE, "r");
  require(in != NULL, "Input file missing!");
  require(fscanf(in, "%lf %lf", &fx, &fy) == 2, "Corrupted input file!");
  fclose(in);
  const double D = distance(x, y, fx, fy);
  require(D > 1.0 + EPS && D < D_MAX - EPS, "Corrupted input file!");
  play();
  require(found, "Point not found!");
  if (steps <= int(ceil(D)) + 50)
    result(5, "Ok!");
  else if (steps <= int(ceil(D)) + 100)
    result(3, "Ok!");
  else if (steps <= int(ceil(1.5 * D)) + 100)
    result(1, "Ok!");
  else
    result(0, "Too many steps!");
  return 0;
}
