#include <bits/stdc++.h>

using namespace std;

const int N = 100000;

const int INF = (1 << 30) - 1;

struct Info {
  int info[4];
  Info() {
    for(int i = 0; i < 4; ++i)
      info[i] = 0;
  }

  Info(const int info[4]) {
    for(int i = 0; i < 4; ++i) {
      this->info[i] = info[i];
    }
  }

  Info(initializer_list<int> il) {
    std::vector<int> li(il.begin(), il.end());
    assert(li.size() == 4);
    for(size_t i = 0; i < 4; ++i)
      info[i] = li[i];
  }

  void update(const Info &rhs) {
    for(int i = 0; i < 4; ++i)
      info[i] = min(info[i], rhs.info[i]);
  }

  bool operator== (const Info &rhs) const {
    for(int i = 0; i < 4; ++i) 
      if(info[i] != rhs.info[i])
        return 0;

    return 1;
  }

  bool operator!= (const Info &rhs) const {
    return !(*this == rhs);
  }
};

const Info dummy({INF, INF, INF, INF});

template<typename Info>
struct AINT {
private:


  struct Node {
    Node *L, *R;
    Info info; 

    Node():
      L(0),
      R(0) {

      }

    Node(Info info):
      L(0),
      R(0),
      info(info) {

      }
  }* root;

public:

  AINT():
    root(0) {

    }

  Info query(Node *& nod, int st, int dr, int lo, int hi);
  Info query(int st, int dr);

  void update(Node *& nod, int st, int dr, int poz, Info val);
  void update(int poz, Info val);
};

template<typename Info>
void AINT<Info>::update(int poz, Info val) {
  update(root, 1, N, poz, val);
}

template<typename Info>
void AINT<Info>::update(Node *& nod, int st, int dr, int poz, Info val) {
  if(nod == 0) 
    nod = new Node(val);
  if(st == dr) {
    nod->info = val;
    return;
  }
  const int mid = (st + dr) / 2;
  if(poz <= mid)
    update(nod->L, st, mid, poz, val);
  else
    update(nod->R, mid + 1, dr, poz, val);

  nod->info.update(val);
}

template<typename Info>
Info AINT<Info>::query(Node *& nod, int st, int dr, int lo, int hi) {
  if(nod == 0)
    return dummy;
  if(lo <= st && dr <= hi) {
    return nod->info;
  }

  const int mid = (st + dr) / 2;

  Info ret = dummy;

  if(lo <= mid)
    ret.update(query(nod->L, st, mid, lo, hi));

  if(mid + 1 <= hi)
    ret.update(query(nod->R, mid + 1, dr, lo, hi));

  return ret;
}

template<typename Info>
Info AINT<Info>::query(int st, int dr) {
  return query(root, 1, N, st, dr);
}

struct AINT2D {
private:

  struct Node {
    Node *L, *R;
    AINT<Info> aint;

    Node():
      L(0),
      R(0) {

      }

    Info query(int y1, int y2) {
      return aint.query(y1, y2);
    }

    void update(int y, Info val) {
      aint.update(y, val);
    }
  }* root;

public:

  AINT2D():
    root(0) {

    }

  Info query(Node *& nod, int st, int dr, int x1, int x2, int y1, int y2);
  Info query(int x1, int x2, int y1, int y2);

  void update(Node *& nod, int st, int dr, int x, int y, Info val);
  void update(int x, int y, Info val);
};

Info AINT2D::query(Node *& nod, int st, int dr, int x1, int x2, int y1, int y2) {
  if(nod == 0)
    return dummy;

  if(x1 <= st && dr <= x2) {
    return nod->query(y1, y2);
  }

  const int mid = (st + dr) / 2;

  Info ret = dummy;

  if(x1 <= mid)
    ret.update(query(nod->L, st, mid, x1, x2, y1, y2));

  if(mid + 1 <= x2)
    ret.update(query(nod->R, mid + 1, dr, x1, x2, y1, y2));

  return ret;
}

Info AINT2D::query(int x1, int x2, int y1, int y2) {
  return query(root, 1, N, x1, x2, y1, y2);
}

void AINT2D::update(Node *& nod, int st, int dr, int x, int y, Info val) {
  if(nod == 0)
    nod = new Node();

  nod->update(y, val);

  if(st == dr)
    return;

  const int mid = (st + dr) / 2;

  if(x <= mid)
    update(nod->L, st, mid, x, y, val);
  else
    update(nod->R, mid + 1, dr, x, y, val);


}
void AINT2D::update(int x, int y, Info val) {
  return update(root, 1, N, x, y, val);
}

struct point {
  int x, y;
};

istream& operator>>(istream& cin, point &p) {
  cin >> p.x >> p.y;
  return cin;
}

vector<point> vp;

int query(AINT2D &aint, point p) {
  const int x = p.x,
            y = p.y;

  Info UL = aint.query(1, x, y, N),
       UR = aint.query(x, N, y, N),
       DL = aint.query(1, x, 1, y),
       DR = aint.query(x, N, 1, y);


  int ul = UL.info[0] + (x - y), 
      ur = UR.info[1] + (-x - y),
      dl = DL.info[2] + (x + y),
      dr = DR.info[3] + (-x + y);

  vector<int> ans;

  if(UL != dummy)
    ans.push_back(ul);

  if(UR != dummy)
    ans.push_back(ur);

  if(DL != dummy)
    ans.push_back(dl);
  
  if(DR != dummy)
    ans.push_back(dr);

  if(ans.empty())
    return 0;

  return accumulate(ans.begin(), ans.end(), ans[0], [](const int &a, const int &b) {
      return min(a, b);
      });
}

void insert(AINT2D &aint, point p) {
  const int x = p.x,
        y = p.y;

  const int a = x,
        b = y;

  aint.update(x, y, {b - a, a + b, - a - b, a - b});
}

int main() {
  AINT2D aint;
  int n;
  ifstream in("mindist.in");
  in >> n;
  for(int i = 0; i < n; ++i) {
    point p;
    in >> p;
    vp.push_back(p);
  }
  in.close();

  ofstream out("mindist.out");
  for(auto p: vp) {
    out << query(aint, p) << "\n";

    insert(aint, p);
  }
  out.close();
  return 0;
}
