#include <cstdio>
#include <cstdlib>
#include <vector>
#include <queue>
#include <algorithm>
using namespace std;

const int nmax = 55, flmax = 2600, inf = 0x3f3f3f3f;

int n, w[nmax], g[nmax][nmax], cap[flmax][flmax], flow[flmax][flmax], father[flmax], source, sink;
vector<int> fg[flmax];

bool bfs()
{
	for (int i = source; i <= sink; ++ i)
		father[i] = -1;
	queue<int> q;
	q.push(source);
	father[source] = 0;

	while (!q.empty())
	{
		int node = q.front();
		q.pop();

		if (node == sink) break;

		for (int i = 0; i < fg[node].size(); ++ i)
		{
			int vec = fg[node][i];
			if (father[vec] == -1 && cap[node][vec] > flow[node][vec])
			{
				father[vec] = node;
				q.push(vec);
			}
		}
	}
	return father[sink] != -1;
}

int maxFlow()
{
	int ans = 0;
	while (bfs())
	{
		for (int i = 0; i < fg[sink].size(); ++ i)
		{
			int vec = fg[sink][i];
			if (father[vec] != -1 && cap[vec][sink] != flow[vec][sink])
			{
				father[sink] = vec;
				int minFlow = inf;
				for (int node = sink; node != source; node = father[node])
					minFlow = min(minFlow, cap[father[node]][node] - flow[father[node]][node]);
				for (int node = sink; node != source; node = father[node])
				{
					flow[father[node]][node] += minFlow;
					flow[node][father[node]] -= minFlow;
				}
				ans += minFlow;
			}
		}
	}
	return ans;
}

bool checkWinner(int player, int won)
{
	for (int i = 1; i <= n; ++ i)
		if (i != player && w[i] > won) //n00b
			return 0;

	source = 1;
	int cntPairs = n * n;
	sink = 1 + cntPairs + n + 1;

	for (int i = source; i <= sink; ++ i)
	{
		for (int j = source; j <= sink; ++ j)
			cap[i][j] = flow[i][j] = 0;
		fg[i].clear();
	}

	int currentNode = 1, total = 0;
	for (int i = 1; i <= n; ++ i)
		for (int j = i + 1; j <= n; ++ j)
			if (i != player && j != player)
			{
				currentNode ++;
				fg[source].push_back(currentNode);
				fg[currentNode].push_back(source);
				cap[source][currentNode] = g[i][j];
				total += g[i][j];

				int other = 1 + cntPairs + i;
				fg[currentNode].push_back(other);
				fg[other].push_back(currentNode);
				cap[currentNode][other] = inf;

				other = 1 + cntPairs + j;
				fg[currentNode].push_back(other);
				fg[other].push_back(currentNode);
				cap[currentNode][other] = inf;
			}

	for (int i = 1; i <= n; ++ i)
		if (i != player)
		{
			int node = 1 + cntPairs + i;
			fg[node].push_back(sink);
			fg[sink].push_back(node);
			cap[node][sink] = won - w[i];
		}

	return maxFlow() == total;
}

int main()
{
	freopen("tournament.in", "r", stdin);
	freopen("tournament.out", "w", stdout);

	scanf("%i", &n);
	for (int i = 1; i <= n; ++ i)
		scanf("%i", &w[i]);
	for (int i = 1; i <= n; ++ i)
		for (int j = 1; j <= n; ++ j)
			scanf("%i", &g[i][j]);

	vector<int> ans;

	for (int i = 1; i <= n; ++ i)
	{
		int won = w[i];
		for (int j = 1; j <= n; ++ j)
			won += g[i][j];

		if (checkWinner(i, won)) ans.push_back(i - 1);
	}

	printf("%i\n", ans.size());
	for (int i = 0; i < ans.size(); ++ i)
		printf("%i ", ans[i]);

	return 0;
}