/**
 * Author: Andrei Heidelbacher
 * Task: Tournament
 * Time complexity: O(N * 2^M)
 * Space complexity: O(N^2 + M)
 * Expected score: 20 points
 */

#include <fstream>
#include <algorithm>
#include <vector>

using namespace std;

const char IN_FILE[] = "tournament.in";
const char OUT_FILE[] = "tournament.out";

inline int getBit(const int mask, const int bit) {
  return (mask >> bit) & 1;
}

int main() {
  ifstream in(IN_FILE);
  int n;
  in >> n;
  vector<int> wins = vector<int>(n);
  vector<vector<int>> remaining = vector<vector<int>>(n, vector<int>(n));
  for (int x = 0; x < n; ++x)
    in >> wins[x];
  for (int x = 0; x < n; ++x)
    for (int y = 0; y < n; ++y)
      in >> remaining[x][y];
  in.close();

  vector<pair<int, int>> matches;
  for (int i = 0; i < n; ++i)
    for (int j = i + 1; j < n; ++j)
      for (int k = 0; k < remaining[i][j]; ++k)
        matches.push_back(make_pair(i, j));
  vector<bool> isChampion = vector<bool>(n, false);
  for (int mask = 0; mask < (1 << int(matches.size())); ++mask) {
    vector<int> scores = wins;
    for (int i = 0; i < int(matches.size()); ++i)
      if (getBit(mask, i))
        ++scores[matches[i].first];
      else
        ++scores[matches[i].second];
    int maxScore = 0;
    for (int i = 0; i < n; ++i)
      maxScore = max(maxScore, scores[i]);
    for (int i = 0; i < n; ++i)
      if (scores[i] == maxScore)
        isChampion[i] = true;
  }
  vector<int> champions;
  for (int i = 0; i < n; ++i)
    if (isChampion[i])
      champions.push_back(i);

  ofstream out(OUT_FILE);
  out << int(champions.size()) << "\n";
  for (int i = 0; i < int(champions.size()); ++i)
    out << champions[i] << " ";
  out << "\n";
  out.close();
  return 0;
}
