#include <cstdio>
#include <cstring>
#include <queue>
#include <vector>
#define MAXN 55
using namespace std;

const int source = 0;
int sink, offset;
int n, nnodes, w[MAXN], g[MAXN][MAXN], cap[MAXN * MAXN][MAXN * MAXN], flow[MAXN * MAXN][MAXN * MAXN];
int nodeIdx[MAXN][MAXN], bk[MAXN * MAXN];
vector<int> sol, G[MAXN * MAXN];

void initialise() {
    int cnt = 0;

    for(int i = 1; i <= n; ++i)
        for(int j = i + 1; j <= n; ++j)
            nodeIdx[i][j] = (++cnt);
    
    offset = cnt;
    nnodes = sink = cnt + n + 1;
}

void buildFlowGraph(int winner, int score) {
    memset(cap, 0, sizeof(cap));
    memset(flow, 0, sizeof(flow));
    for(int i = 0; i <= nnodes; ++i)
        G[i].clear();

    for(int i = 1; i <= n; ++i) {
        if(i == winner) continue;
        for(int j = i + 1; j <= n; ++j) {
            if(j != winner) {
                cap[source][nodeIdx[i][j]]     = g[i][j];
                cap[nodeIdx[i][j]][offset + i] = g[i][j];
                cap[nodeIdx[i][j]][offset + j] = g[i][j];
                
                G[source].push_back(nodeIdx[i][j]);
                G[nodeIdx[i][j]].push_back(source);

                G[nodeIdx[i][j]].push_back(offset + i);
                G[offset + i].push_back(nodeIdx[i][j]);

                G[nodeIdx[i][j]].push_back(offset + j);
                G[offset + j].push_back(nodeIdx[i][j]);
            }
        }
    }

    for(int i = 1; i <= n; ++i) {
        cap[offset + i][sink] = score - w[i];
        G[offset + i].push_back(sink);
        G[sink].push_back(offset + i);
    }
}

bool BFS() {
    for(int i = 0; i <= nnodes; ++i)
        bk[i] = -1;

    queue<int> q;
    
    q.push(source);
    bk[source] = -2;

    while(!q.empty()) {
        int x = q.front();
        q.pop();

        if(x == sink) continue;

        for(auto y: G[x])
            if(bk[y] == -1 && flow[x][y] < cap[x][y]) {
                bk[y] = x;
                q.push(y);
            }
    }

    return bk[sink] != -1;
}

void solveFlow() {
    while(BFS()) {
        for(int i = 1; i <= n; ++i) {
            if(bk[offset + i] != -1) {
                int x = offset + i;
                int fx = cap[x][sink] - flow[x][sink];

                while(fx && bk[x] >= 0) {
                    fx = min(fx, cap[bk[x]][x] - flow[bk[x]][x]);
                    x = bk[x];
                }

                if(!fx) continue;
                x = offset + i;

                flow[x][sink] += fx;
                flow[sink][x] -= fx;

                while(bk[x] >= 0) {
                    flow[bk[x]][x] += fx;
                    flow[x][bk[x]] -= fx;

                    x = bk[x];
                }
            }
        }
    }
}

int main() {
    freopen("tournament.in", "r", stdin);
    freopen("tournament.out", "w", stdout);

    scanf("%d", &n);

    for(int i = 1; i <= n; ++i)
        scanf("%d", &w[i]);

    for(int i = 1; i <= n; ++i)
        for(int j = 1; j <= n; ++j)
            scanf("%d", &g[i][j]);

    initialise();

    for(int i = 1; i <= n; ++i) {
        int score = w[i];

        for(int j = 1; j <= n; ++j)
            score += g[i][j];

        bool ok = 1;
        for(int j = 1; j <= n; ++j)
            if(w[j] > score)
                ok = 0;
        if(!ok) continue;

        buildFlowGraph(i, score);
        solveFlow();
        
        for(int i = 1; i <= offset; ++i)
            if(flow[source][i] < cap[source][i]) {
                ok = 0;
                break;
            }

        if(ok) sol.push_back(i - 1);
    }

    printf("%d\n", (int) sol.size());
    for(auto x: sol)
        printf("%d ", x);
    printf("\n");

    return 0;
}
