/**
 * Author: Andrei Heidelbacher
 * Task: Asalt
 * Time complexity: O(N)
 * Space complexity: O(N)
 * Expected score: 15 points
 */

#include <cmath>

#include <algorithm>
#include <vector>
#include <map>

#include "header.h"

using namespace std;

const double EPS = 1e-7;
const double PI = acos(-1.0);
const double oo = 1e9;

class Point {
 public:
  double x, y;

  Point() {}

  Point(const double _x, const double _y):
   x(_x),
   y(_y) {}
};

map<pair<int, int>, double> distances;

inline double distance(const Point &a, const Point &b) {
  return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

inline double getDistance(const int i, const int j) {
  if (j < i)
    return getDistance(j, i);
  if (i == j)
    return 0.0;
  if (distances.find(make_pair(i, j)) != distances.end())
    return distances[make_pair(i, j)];
  return distances[make_pair(i, j)] = query(i, j);
}

void recover(int N) {
  const int n = N;
  vector<Point> points = vector<Point>(n);
  int index = 0;
  do {
    ++index;
    points[index] = Point(0, getDistance(0, index));
  } while (abs(points[index].y) < EPS);
  const double a = getDistance(0, index);
  points[0] = Point(0.0, 0.0);
  points[1] = Point(0.0, a);
  for (int i = 2; i < n; ++i) {
    const double b = getDistance(0, i);
    const double c = getDistance(index, i);
    if (abs(a + c - b) < EPS || abs(b + c - a) < EPS)
      points[i] = Point(0.0, b);
    else
      points[i] = Point(0.0, -b);
  }
  double *x = new double[n];
  double *y = new double[n];
  for (int i = 0; i < n; ++i) {
    x[i] = points[i].x;
    y[i] = points[i].y;
  }
  sendRecovered(x, y);
}
