/**
 * Author: Andrei Heidelbacher
 * Task: Asalt
 * Grader
 */

#include <cstdio>
#include <cmath>
#include <cassert>

#include <vector>
#include <algorithm>

#include "header.h"

using namespace std;

static const char IN_FILE[] = "asalt.in";
static const double EPS = 1e-4;

static int n;
static vector<double> inputX, inputY;
static int queryCount = 0;

static inline void result(const int score, const char *message) {
  fprintf(stdout, "%d %s\n", score, message);
  exit(0);
}

static inline void require(const bool condition, const char *message) {
  if (!condition)
    result(0, message);
}

static inline double distance(
    const double x1,
    const double y1,
    const double x2,
    const double y2) {
  return sqrt((x1 - x2) * (x1 - x2) + (y1 - y2) * (y1 - y2));
}

static inline bool equal(const double x, const double y) {
  if (abs(x - y) <= EPS)
    return true;
  if (abs(x) <= EPS || abs(y) <= EPS)
    return false;
  if (abs((x - y) / x) <= EPS)
    return true;
  if (abs((x - y) / y) <= EPS)
    return true;
  return false;
}

double query(int a, int b) {
  require(0 <= a && a < n && 0 <= b && b < n && a != b, "Invalid query!");
  ++queryCount;
  return distance(inputX[a], inputY[a], inputX[b], inputY[b]);
}

void sendRecovered(double *x, double *y) {
  const int a = 0;
  int b = 1;
  while (b < n && abs(distance(inputX[a], inputY[a], inputX[b], inputY[b])) < EPS) {
    require(abs(distance(x[a], y[a], x[b], y[b])) < EPS, "Incorrect distance!");
    ++b;
  }
  const double AB = distance(x[a], y[a], x[b], y[b]);
  const double correctAB = distance(inputX[a], inputY[a], inputX[b], inputY[b]);
  require(equal(AB, correctAB), "Incorrect distance!");
  int c = b + 1;
  while (c < n) {
    const double AC = distance(x[a], y[a], x[c], y[c]);
    const double correctAC = distance(inputX[a], inputY[a], inputX[c], inputY[c]);
    const double BC = distance(x[b], y[b], x[c], y[c]);
    const double correctBC = distance(inputX[b], inputY[b], inputX[c], inputY[c]);
    require(equal(AC, correctAC), "Incorrect distance!");
    require(equal(BC, correctBC), "Incorrect distance!");
    if (equal(correctAB, correctAC + correctBC) ||
        equal(correctAC, correctAB + correctBC) ||
        equal(correctBC, correctAB + correctAC))
      ++c;
    else
      break;
  }
  for (int i = c + 1; i < n; ++i) {
    const double AI = distance(x[a], y[a], x[i], y[i]);
    const double correctAI = distance(inputX[a], inputY[a], inputX[i], inputY[i]);
    require(equal(AI, correctAI), "Incorrect distance!");
    const double BI = distance(x[b], y[b], x[i], y[i]);
    const double correctBI = distance(inputX[b], inputY[b], inputX[i], inputY[i]);
    require(equal(BI, correctBI), "Incorrect distance!");
    const double CI = distance(x[c], y[c], x[i], y[i]);
    const double correctCI = distance(inputX[c], inputY[c], inputX[i], inputY[i]);
    require(equal(CI, correctCI), "Incorrect distance!");
  }
  int score = 5;
  if (3 * n < queryCount)
    score = 3;
  if (10 * n < queryCount)
    score = 1;
  result(score, "OK!");
}

int main() {
  FILE *in = fopen(IN_FILE, "r");
  require(in != NULL, "Missing input file!");
  require(fscanf(in, "%d", &n) == 1, "Invalid input file!");
  inputX = inputY = vector<double>(n);
  for (int i = 0; i < n; ++i)
    require(fscanf(in, "%lf %lf", &inputX[i], &inputY[i]) == 2, "Invalid input file!");
  fclose(in);
  recover(n);
  result(0, "Points not recovered!");
  return 0;
}
