#include <cstdio>
#include <vector>
#include <cstring>
#include <ctime>
#include <algorithm>

using namespace std;

#define MaxN 401

int N, K;
int sizeSmall, sizeBig;
int smallSocks, bigSocks;

struct RandGen {
    unsigned x, y, w, z;
   
    RandGen() {
      x = 123456789;
      y = 362436069;
      z = 521288629;
      w = clock();;
   }

    unsigned nextInt() {
        unsigned t = x ^ (x << 11); 
        x = y;
        y = z; 
        z = w;
        w ^= (w >> 19) ^  t ^ (t >> 8);
        return w;
    }
   
   int random(int N) {
       //TODO: not debiased
       return nextInt() % N;
   }
   
    double randDouble() {
        return nextInt() / (double) (1ll << 32);
    }
};

struct SockBag {
    int smallSocks, bigSocks;
    short smallColors[MaxN];
    short bigColors[MaxN];
    RandGen rng;
    
    int pick(short colors[], int &numSocks) {
        const int sockIndex = rng.random(numSocks);
        swap(colors[sockIndex], colors[--numSocks]);
        return colors[numSocks];
    }
    
    int pickSockColor() {
        const int smallWeight = smallSocks * sizeSmall;
        const int totalWeight = smallWeight + bigSocks * sizeBig;
        if (rng.random(totalWeight) < smallWeight) {
            return pick(smallColors, smallSocks);
        } else {
            return pick(bigColors, bigSocks);
        }
    }
    
    bool runMonteCarlo() {
        bool colorPicked[MaxN] = {false};
        this->smallSocks = ::smallSocks;
        this->bigSocks = ::bigSocks;
        for (int i = 0; i < K; i++) {
            int color = pickSockColor();
            if (colorPicked[color]) {
                return true;
            }
            colorPicked[color] = true;
        }
        return false;
    }
};

SockBag alexsSockBag;

void ReadInput() {
    scanf("%d %d", &N, &K);
    scanf("%d %d", &sizeSmall, &sizeBig);
    for (int i = 0; i < N; i++) {
        int color, size;
        scanf("%d %d", &color, &size);
        if (size == 0) {
            alexsSockBag.smallColors[smallSocks++] = color;
        } else {
            alexsSockBag.bigColors[bigSocks++] = color;
        }
    }
}

void Solve() {
    const double startTime = clock();
    double goodSamples = 0.0;
    int numIter = 0;
    while (clock() - startTime < CLOCKS_PER_SEC * 0.95) {
        goodSamples += alexsSockBag.runMonteCarlo();
        numIter++;
    }
    printf("%.9lf\n", goodSamples / numIter);
}

int main() {
#ifndef ONLINE_JUDGE
    freopen("expected.in", "rb", stdin);
    freopen("expected.out", "wb", stdout);
#endif
    ReadInput();
    Solve();
}
