#include <cassert>
#include <fstream>
#include <algorithm>
#include <array>
#include <iostream>
#include <iomanip>
#include <vector>
using namespace std;

const int kMaxN = 400 + 1;

vector<double> SmallSocksChx(const array<double, 2>& chx, int k, int small, int big) {
  vector<double> prev(small + 1, 0.0), next;
  prev[0] = 1.0;
  for (int num = 1; num <= k; num += 1) {
    next = vector<double>(small + 1, 0.0);
    for (int current_small = max(0, num - big); current_small <= min(small, num); current_small += 1) {
      int remaining_small = small - current_small;
      int remaining_big = big - (num - current_small);
      //cerr << num << '\t' << current_small << '\t' << remaining_small << '\t' << remaining_big << '\n';
      assert(0 <= remaining_small and remaining_small <= small);
      assert(0 <= remaining_big and remaining_big <= big);

      // this is 0
      if (current_small != 0) {
        next[current_small] +=
            prev[current_small - 1] * (remaining_small + 1) * chx[0] /
            ((remaining_small + 1) * chx[0] + (remaining_big) * chx[1]);
      }

      // this is 1
      if (num - current_small != 0) {
        next[current_small] +=
            prev[current_small] * (remaining_big + 1) * chx[1] /
            ((remaining_small) * chx[0] + (remaining_big + 1) * chx[1]);
      }
    }
    prev = next;
  }

  return prev;
}

double Solve(const array<double, 2>& chx, const int& k,
             const vector<pair<int, bool>>& socks) {
  vector<int> unique_colors = {};
  for (const auto& sock : socks) {
    unique_colors.push_back(sock.first);
  }

  sort(unique_colors.begin(), unique_colors.end());
  unique_colors.resize(unique(unique_colors.begin(), unique_colors.end()) -
                       unique_colors.begin());

  vector<array<int, 2>> num_colors(unique_colors.size(), {{0, 0}});
  for (const auto& sock : socks) {
    num_colors[lower_bound(unique_colors.begin(), unique_colors.end(),
                           sock.first) -
               unique_colors.begin()][sock.second] += 1;
  }

  int big_socks_num = 0;
  for (auto sock : socks) {
    big_socks_num += sock.second;
  }

  int small_socks_num = int(socks.size()) - big_socks_num;

  auto small_socks_chx = SmallSocksChx(chx, k, small_socks_num, big_socks_num);
  //for (int i = 0; i < int(small_socks_chx.size()); i += 1) {
    //cerr << i << '\t' << small_socks_chx[i] << '\n';
  //}

  array<array<double, kMaxN>, kMaxN> dp;
  dp[0][0] = 1.0;

  for (int current_kind = 0; current_kind < int(unique_colors.size()); current_kind += 1) {
    for (int num = k; num >= 1; num -= 1) {
      for (int current_small = max(0, num - big_socks_num); current_small <= min(small_socks_num, num); current_small += 1) {
        int remaining_small = small_socks_num - current_small;
        int remaining_big = big_socks_num - (num - current_small);
        assert(0 <= remaining_small and remaining_small <= small_socks_num);
        assert(0 <= remaining_big and remaining_big <= big_socks_num);

        // this is 0
        if (current_small != 0 and num_colors[current_kind][0]) {
          dp[num][current_small] += dp[num - 1][current_small - 1] *
                                    (num_colors[current_kind][0]) *
                                    (current_small);
        }

        // this is 1
        if (num - current_small != 0 and num_colors[current_kind][1]) {
          dp[num][current_small] += dp[num - 1][current_small] *
                                    (num_colors[current_kind][1]) *
                                    (num - current_small);
        }
      }
    }
  }

  vector<double> fact(socks.size() + 1, 1.0);
  for (int i = 1; i <= int(socks.size()); i += 1) {
    fact[i] = fact[i - 1] * i;
  }

  //for (int i = 0; i <= small_socks_num; i += 1) {
    //cerr << "@" << dp[k][i] << '\n';
  //}

  double rez = 0.0;
  for (int small_socks = max(0, k - big_socks_num); small_socks <= min(k, small_socks_num); small_socks += 1) {
    int big_socks = k - small_socks;

    rez += small_socks_chx[small_socks] *
           (1.0 -
            dp[k][small_socks] * (fact[small_socks_num - small_socks] /
                fact[small_socks_num]) * (fact[big_socks_num - big_socks] /
                fact[big_socks_num]));
  }

  return rez;
}

int main() {
  ifstream cin("expected.in");
  ofstream cout("expected.out");
  array<double, 2> chx;

  int n, k; cin >> n >> k;
  cin >> chx[0] >> chx[1];

  vector<pair<int, bool>> socks;
  socks.reserve(n);

  for (int i = 0; i < n; i += 1) {
    int color; bool size; cin >> color >> size;
    socks.push_back({color, size});
  }

  cout << fixed << setprecision(9) << Solve(chx, k, socks) << '\n';
  return 0;
}
