/**
 * Author: Andrei Heidelbacher
 * Task: Politic
 * Time complexity: O(2^N * N^2)
 * Space complexity: O(N)
 * Expected score: 10 points
 */

#include <fstream>
#include <vector>
#include <algorithm>
#include <set>

using namespace std;

const char IN_FILE[] = "politic.in";
const char OUT_FILE[] = "politic.out";

inline int getBit(const int mask, const int bit) {
  return (mask >> bit) & 1;
}

vector<int> solveGraph(const vector<int> &fathers) {
  const int size = int(fathers.size());
  vector<int> remaining = vector<int>(size + 1, size);
  for (int mask = 0; mask < (1 << size); ++mask) {
    int remainingNow = 0, bitCount = 0;
    for (int u = 0; u < size; ++u) {
      if (getBit(mask, u) == 1) {
        ++bitCount;
        continue;
      }
      vector<bool> visited = vector<bool>(size, false);
      int v = fathers[u];
      for (; getBit(mask, v) == 1 && !visited[v]; v = fathers[v])
        visited[v] = true;
      if (getBit(mask, v) == 0)
        ++remainingNow;
    }
    remaining[bitCount] = min(remaining[bitCount], remainingNow);
  }
  return remaining;
}

vector<int> readInput() {
  ifstream in(IN_FILE);
  int size;
  in >> size;
  vector<int> fathers = vector<int>(size);
  for (int u = 0; u < size; ++u) {
    in >> fathers[u];
    --fathers[u];
  }
  in.close();
  return fathers;
}

void writeOutput(const vector<int> &remaining) {
  ofstream out(OUT_FILE);
  for (int i = 1; i < int(remaining.size()); ++i)
    out << remaining[i] << "\n";
  out.close();
}

int main() {
  const vector<int> fathers = readInput();
  const vector<int> remaining = solveGraph(fathers);
  writeOutput(remaining);
  return 0;
}
