/**
 * Author: Andrei Heidelbacher
 * Task: Politic
 * Time complexity: O(N^2 * logN)
 * Space complexity: O(N)
 * Expected score: 0-10 points
 */

#include <fstream>
#include <vector>
#include <algorithm>
#include <queue>
#include <set>

using namespace std;

const char IN_FILE[] = "politic.in";
const char OUT_FILE[] = "politic.out";

typedef vector<vector<int>> Graph;

vector<set<int>> findCycles(const vector<int> &fathers) {
  const int size = int(fathers.size());
  vector<int> visited = vector<int>(size, -1);
  vector<set<int>> cycles;
  for (int u = 0; u < size; ++u) {
    if (visited[u] == -1) {
      int v = u;
      do {
        visited[v] = u;
        v = fathers[v];
      } while (visited[v] == -1);
      if (visited[v] == u) {
        set<int> cycle;
        const int firstOnCycle = v;
        do {
          cycle.insert(v);
          v = fathers[v];
        } while (v != firstOnCycle);
        cycles.push_back(cycle);
      }
    }
  }
  return cycles;
}

int solveGraph(const vector<int> &fathers, const int maxEliminated) {
  const int size = int(fathers.size());
  Graph graph = Graph(size);
  for (int u = 0; u < size; ++u)
    graph[fathers[u]].push_back(u);
  vector<set<int>> cycles = findCycles(fathers);
  vector<pair<double, int>> sortedCycles;
  const int cycleCount = int(cycles.size());
  for (int i = 0; i < cycleCount; ++i) {
    int degreeSum = 0;
    for (const int &cycleNode: cycles[i])
      degreeSum += int(graph[cycleNode].size());
    const int length = int(cycles[i].size());
    sortedCycles.push_back(make_pair(1.0 * degreeSum / length, i));
  }
  sort(sortedCycles.rbegin(), sortedCycles.rend());
  priority_queue<pair<int, int>> heap;
  vector<bool> isEliminated = vector<bool>(size, false);
  int eliminated = 0;
  for (int i = 0; i < cycleCount; ++i) {
    const set<int> cycle = cycles[sortedCycles[i].second];
    if (eliminated + int(cycle.size()) <= maxEliminated) {
      eliminated += int(cycle.size());
      for (const int &cycleNode: cycle) {
        isEliminated[cycleNode] = true;
        ++eliminated;
        for (const int &root: graph[cycleNode])
          if (cycle.find(root) == cycle.end())
            heap.push(make_pair(int(graph[root].size()), root));
      }
    }
  }
  while (!heap.empty() && eliminated < maxEliminated) {
    const int root = heap.top().second;
    heap.pop();
    isEliminated[root] = true;
    ++eliminated;
    for (const int &son: graph[root])
      heap.push(make_pair(int(graph[son].size()), son));
  }
  for (int u = 0; u < size && eliminated < maxEliminated; ++u) {
    if (!isEliminated[u]) {
      isEliminated[u] = true;
      ++eliminated;
    }
  }
  int remaining = 0;
  for (int u = 0; u < size; ++u)
    if (!isEliminated[u] && !isEliminated[fathers[u]])
      ++remaining;
  return remaining;
}

vector<int> readInput() {
  ifstream in(IN_FILE);
  int size;
  in >> size;
  vector<int> fathers = vector<int>(size);
  for (int u = 0; u < size; ++u) {
    in >> fathers[u];
    --fathers[u];
  }
  in.close();
  return fathers;
}

void writeOutput(const vector<int> &remaining) {
  ofstream out(OUT_FILE);
  for (int i = 1; i < int(remaining.size()); ++i)
    out << remaining[i] << "\n";
  out.close();
}

int main() {
  const vector<int> fathers = readInput();
  vector<int> remaining = vector<int>(int(fathers.size()) + 1, int(fathers.size()));
  for (int i = 1; i < int(remaining.size()); ++i)
    remaining[i] = solveGraph(fathers, i);
  writeOutput(remaining);
  return 0;
}
